@@ -5,24 +5,17 @@ import math
 import re
 import shlex
 import sys
-from typing import List, Tuple, Dict
+from typing import List, Tuple, Dict, Union
 
 import configargparse
 
-try:
-    from picker.action import Action
-    from picker.clipboarder import Clipboarder
-    from picker.typer import Typer
-    from picker.selector import Selector
-    from picker.paths import *
-except ModuleNotFoundError:
-    from action import Action
-    from clipboarder import Clipboarder
-    from typer import Typer
-    from selector import Selector
-    from paths import *
+from .clipboarder import Clipboarder
+from .models import Action, CANCEL, DEFAULT, Shortcut
+from .paths import *
+from .selector import Selector
+from .typer import Typer
 
-__version__ = '5.4.0'
+__version__ = '5.5.0'
 
 
 class Rofimoji:
@@ -221,19 +214,20 @@ class Rofimoji:
         return parsed_args
 
     def standalone(self) -> None:
-        returncode, stdout = self.open_main_rofi_window()
+        action, value = self.open_main_rofi_window()
 
-        if returncode == 1:
+        if action == CANCEL():
             sys.exit()
-        else:
-            if 10 <= returncode <= 19:
-                characters = self.load_recent_characters(self.args.max_recent)[returncode - 10].strip()
-            else:
-                self.choose_action_from_return_code(returncode)
-                characters = self.process_chosen_characters(stdout.splitlines())
+        elif action != DEFAULT():
+            self.args.actions = [action]
 
-            self.save_characters_to_recent_file(characters)
-            self.execute_action(characters)
+        if isinstance(value, Shortcut):
+            characters = self.load_recent_characters(self.args.max_recent)[value.index]
+        else:
+            characters = self.process_chosen_characters(value.splitlines())
+
+        self.save_characters_to_recent_file(characters)
+        self.execute_action(characters)
 
     def mode_show_characters(self) -> None:
         recent_characters = self.format_recent_characters()
@@ -245,7 +239,7 @@ class Rofimoji:
 
     def mode_act_on_selection(self, chosen_character: str, returncode: int) -> None:
         if 10 <= returncode <= 19:
-            characters = self.load_recent_characters(self.args.max_recent)[returncode - 10].strip()
+            characters = self.load_recent_characters(self.args.max_recent)[returncode - 10]
             self.save_characters_to_recent_file(characters)
             self.execute_action(characters)
         else:
@@ -337,11 +331,11 @@ class Rofimoji:
         return resolved_file_names
 
     def load_from_file(self, file: Path) -> List[str]:
-        return file.read_text().strip().split('\n')
+        return file.read_text().strip('\n').split('\n')
 
     def load_recent_characters(self, max: int) -> List[str]:
         try:
-            return recents_file_location.read_text().strip().split('\n')[:max]
+            return [char.strip('\n') for char in recents_file_location.read_text().strip('\n').split('\n')][:max]
         except FileNotFoundError:
             return []
 
@@ -351,7 +345,7 @@ class Rofimoji:
 
         return ' | '.join(pairings)
 
-    def open_main_rofi_window(self) -> Tuple[int, str]:
+    def open_main_rofi_window(self) -> Tuple[Union[Action, DEFAULT, CANCEL], Union[str, Shortcut]]:
         return self.selector.show_character_selection(
             self.read_character_files(),
             self.format_recent_characters(),
@@ -428,7 +422,7 @@ class Rofimoji:
                 with old_file_name.open('r') as old_file:
                     index = 0
                     for line in old_file:
-                        if characters != line.strip():
+                        if characters != line.strip('\n'):
                             if index == max_recent - 1:
                                 break
                             new_file.write(line)
@@ -445,7 +439,7 @@ class Rofimoji:
         try:
             with frecency_file_location.open('r') as file:
                 for line in file:
-                    (frecency, character) = line.strip().split(' ')
+                    (frecency, character) = line.strip('\n').split(' ')
                     frecencies[character] = int(frecency)
         except FileNotFoundError:
             pass
@@ -501,22 +495,3 @@ class Rofimoji:
         return cache[1], cache[2]
 
 
-def main():
-    return_value = os.environ.get('ROFI_RETV')
-
-    if return_value is None:
-        Rofimoji().standalone()
-    elif return_value == "0":
-        Rofimoji().mode_show_characters()
-    elif not cache_file_location.is_file():
-        chosen = sys.argv[-1]
-        del sys.argv[-1]
-        Rofimoji().mode_act_on_selection(chosen, int(return_value))
-    else:
-        chosen = sys.argv[-1]
-        del sys.argv[-1]
-        Rofimoji().mode_select_skin_tone(chosen)
-
-
-if __name__ == "__main__":
-    main()
